=======================
The Directory Structure
=======================

::

    /
        grading/  (directory from farm)
            zucc.yml
            Makefile
            grader.c
        submissions/ (created by loader)
            Adams, Austin/
                file1.c
                file2.h
            Gokmen, Cem/
                file1.c
                file2.h
            Leahy, William/
                file1.c
                file2.h
